@@ -70,11 +70,15 @@ class ASTROMER:
         mask   = Input(shape=(self.maxlen, 1),
                     batch_size=None,
                     name='mask')
-
+        length = Input(shape=(self.maxlen,),
+                    batch_size=None,
+                    dtype=tf.int32,
+                    name='length')
 
         placeholder = {'input':serie,
                     'mask_in':mask,
-                    'times':times}
+                    'times':times,
+                    'length':length}
 
         encoder = Encoder(self.num_layers,
                     self.d_model,
@@ -235,11 +239,11 @@ class ASTROMER:
         pbar = tqdm(range(epochs), desc='epoch')
         for epoch in pbar:
             for train_batch in train_dataset:
-                mse = self.train_step(self.model, train_batch, optimizer)
+                mse = self.train_step(train_batch, optimizer)
                 train_mse.update_state(mse)
 
             for valid_batch in valid_dataset:
-                mse = self.valid_step(self.model, valid_batch)
+                mse = self.valid_step(valid_batch)
                 valid_mse.update_state(mse)
 
             msg = 'EPOCH {} - ES COUNT: {}/{} train mse: {:.4f} - val mse: {:.4f}'.format(epoch,
