@@ -737,14 +737,18 @@ def pretraining_numpy(arr, batch_size, shuffle=False, max_obs=100,
 
 
 def pretraining_data(data, batch_size, shuffle=False, max_obs=100,
-                        msk_frac=0.2, rnd_frac=0.1, same_frac=0.1):
+                        msk_frac=0.2, rnd_frac=0.1, same_frac=0.1, mode=None):
     if isinstance(data, list):
         data =  pretraining_numpy(data, batch_size, shuffle=shuffle, max_obs=max_obs,
                         msk_frac=msk_frac, rnd_frac=rnd_frac, same_frac=same_frac)
         return data
     elif isinstance(data, str):
-        data =  pretraining_records_v2(data, batch_size, shuffle=shuffle, max_obs=max_obs,
-                        msk_frac=msk_frac, rnd_frac=rnd_frac, same_frac=same_frac)
+        if mode=="clf":
+            data =  pretraining_records_v2(data, batch_size, shuffle=shuffle, max_obs=max_obs,
+                            msk_frac=msk_frac, rnd_frac=rnd_frac, same_frac=same_frac)
+        else:
+            data =  pretraining_records(data, batch_size, shuffle=shuffle, max_obs=max_obs,
+                            msk_frac=msk_frac, rnd_frac=rnd_frac, same_frac=same_frac)
         return data
     else:
         raise TypeError("pretraining_data only accepts either a list of numpy arrays containing lightcurves or a path to the record file(str)")
\ No newline at end of file
